
# q-expansion of newform 175.10.a.d, downloaded from the LMFDB on 27 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 175
weight = 10
poly_data = [2016, -426, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0], 1], [[276, 25, -1], 6], [[-288, 11, 1], 6]]

hecke_ring_character_values = None
aps_data = [[-7, 0, 1], [-28, 1, 1], [0, 0, 0], [-2401, 0, 0], [-1148, 658, 650], [6594, 175, -3017], [-338898, -1574, -3030], [74284, 2437, -15371], [-628544, 3808, 24200], [1360606, 18914, 54866], [956480, -70302, 55698], [-465206, -60522, -209418], [-4806886, -131894, -163478], [20543724, -65366, -121982], [3456320, -83238, 534778], [-22500870, 450352, -1553376], [-14196700, -49659, -2231195], [63915614, -844773, 589107], [85058596, -47712, -3939816], [98838168, -526260, 3499356], [-114737770, -118516, 9544844], [-320137552, 1679412, -7475532], [366839060, 1977367, 4479559], [168938826, 1815976, -10612104], [215832750, 864850, -33276782], [175124950, 6270235, -9312157], [517502104, -6873462, -17946342], [-608192004, -8208844, 39197964], [10196606, 6778926, 1462446], [-1456992938, -704914, 25708886], [-646426440, -12416012, 13198108], [1109519516, -11460427, 54159589], [1163642102, 40567268, 14101060], [-5452351212, 7278131, -56250397], [-1049208202, 20322260, 111063028], [-2090928784, 13591284, -180999876], [7546938770, 50001239, -37158337], [-2809417100, -60027198, 216387354], [-2370604376, -92651314, -132391378], [-3556276318, 121594395, 192302851], [4679521644, -10041556, 79923444], [-12182618602, -84064911, 123030201], [7564416496, -92650740, 358336124], [-4193166698, 109446162, 296404746], [1044069738, -146823012, -356422164], [7775640488, -35045046, -748413702], [-5084983188, 221074280, -255977680], [8959631632, -98663796, -220743684], [17290910084, -89141989, 897007147], [-13496753578, -458931171, 500018037], [-12893305194, -274790488, 1556666280], [5383177928, -517478024, 1317170848], [28492185218, 431266758, 313800486], [3118364004, -553785813, 1838260347], [-96506412002, 134738008, 92049656], [-54233527768, -411736108, 2039554756], [14470203678, -481952059, -1139234307], [-16445892064, -308601768, 556573704], [41701567978, -297000480, 1295373696], [60731571994, -399991312, 1493343152], [-2183767460, -423882381, -435232461], [-29722533974, 509126513, 1618396745], [-40912279884, -909882197, -706669061], [-159254962216, 1022133048, 4287155032], [12286108982, 1046029718, 969666326], [168906803954, 735598668, -78171428], [-45968391308, -2765137466, 4251579310], [13486829830, -220982454, 5721254658], [-146836160996, 1478583666, 344698922], [-99704829378, -983282083, -1176007483], [-57347344306, -3119021968, -271332032], [-105198692592, 1541162644, -8345003892], [-198570902656, 2574141956, -8002657228], [-118372717078, -1829708692, -10539003124], [149485441380, 6653440010, -40593070], [46217048080, 1284629338, 663388634], [-419001589706, -1075626398, 2795739554], [-11488061102, 3815230467, 4648453851], [92833081418, -2365592530, -2754036314], [457847724698, -3641413434, -23895954762], [-305931218404, -1759027781, 22336510651], [-229810690618, -4575621960, 2077218360], [-423893978760, -4944663472, 14253102408], [395245203150, -2818804394, 4927649734], [-100441021688, 4385700544, -12650593808], [173884857020, 571445448, -17515090256], [351981434562, 9229258584, 12885001752], [-1134555470258, -2326103934, -3643968390], [-724820539730, -3653043583, -9953581687], [-451768337120, 1921856832, -35034710256], [402370101588, 11341683191, 408629031], [-1047626098400, -496857950, -22024210510], [-334461780688, 4844509712, 30240560120], [-286436335372, 8022145936, -55500291224], [148285775708, -20260808736, 21194911128], [547398820920, 8065343580, -15469064436], [1444601390078, 6705267101, -13346869787], [674777766474, -1725999262, 58917566322], [1133563459084, -12865732713, -46758410217], [-1093628229890, 2382916060, 11593843708], [-1848071315148, 3027219118, -18206633690], [232168779906, -26046817580, 10225383204], [1764738857812, -10770612663, -31139926999], [2194098553906, -4462954314, -35149511314], [781355582980, -26035063166, -83542406102], [-1151917665458, -37655286360, 12522515160], [-3393169481044, 3743843089, 15041451649], [-189267720978, 19458573812, -4105755564], [4139549865080, -6716733240, 25335368680], [-2758512013782, 20119527176, -111209313544], [-437824544416, -54712996864, 15504967232], [-440831618150, -6918491202, -79001940786], [2937098052334, -10860815014, -26554812718], [-820805060908, -30860171763, -75721000083], [1624500571416, -21111739180, 115406775764], [-1593695109062, 10067049958, -36134967394], [-5415613098588, -9194964695, -20433816599], [-586438102824, 43511047462, -13906398666], [-3616840291694, 29393672098, 39695691890], [-1816063341860, -9364390294, -94226963950], [2644906814662, 3237519655, -154405141745], [6803559030910, 14332938060, 6531973644], [-2255203958182, -46655444361, 101680180111], [-1292190802308, 18118236136, -111992896224], [-3118224539668, -60084064515, -17468934195], [589656379230, -1658129130, 161627368518], [3317663048630, -14828858814, 153560498370], [-5337579270240, -16365607670, 167240841930], [-7661380614888, 30779337442, 198080967490], [-7605507159614, -36844226595, -21403866555], [2929981462604, 99955751070, -54065992506], [4065972133648, -67270736428, 48942306812], [-2628718900136, -57646531040, 85083653752], [-4584647698710, 31390670374, 178071369238], [4355095151498, -65605150834, 76738035886], [-5362997268622, 99030112818, -196718206062], [-12265396652838, 19798346569, -16013359599], [11131862131348, -48668472369, -131092607169], [3329293568818, -66374180509, -40976144629], [-4438334382510, -17232311866, 63591879630], [-3110250381868, -116999818215, 45537036825], [10563188415094, 42805497672, -21656722648], [2225581331512, -63932745912, 414445754136], [1395606578700, -76927040988, -472112596452], [-1100070604514, -58761605981, 240205609531], [-3214450380344, -78042202210, -82561983154], [3261979684474, 178191979875, 251727911883], [-10194775973242, 56294497274, -150775920854], [9484371805412, 230001630363, -112654046133], [3267820234896, 148496379164, 32972787660], [4093668716578, -92045722986, -396080680554], [-9447184076862, 140545625724, 113617603596], [-11310986987036, -131545110900, -260641653132], [4810052367736, 140522951722, 284909683274], [4465912621996, -132916677348, -128034242076], [-776274555320, 36364998572, 137163986708], [12197824958312, 6862701720, 356477315592], [-904370187518, -71014735938, -38683602418], [5288787099414, -182921194484, -177982402388], [-19712465153122, 107365613067, -309744041069], [-353912373052, -95781334530, 496514284246], [-2667773776026, -35449375752, -470935834152], [13369332923952, 206353785064, 361890959920], [-3944840249868, 167377757485, -98404661235], [-21643379653490, -113713391484, -391347106492], [-4980874310104, -202106619070, 1065671717650], [-9462695969440, 170929805592, -1362169007592], [13956742164442, -145091371263, 938287285545], [22394160681594, 297108813134, 90764423414], [21192403633786, -224177639813, 266091479555], [20416046126308, -314332970000, -564707342872], [10378787992958, 227615102001, -608458908519], [29416563537368, 40936947884, 698203616956], [-27226896932074, 48880878200, -410149388200], [8683839627680, -305357044014, 641860503570], [40839248926826, -139910632316, 368227078996], [25992935414868, -347753634844, 852528064556], [40603493949606, 199871569394, -110608509726], [-13704919214952, 282933418180, -849291325148], [-33164611886434, 366484375419, -880715444349], [17855550430424, -384722912560, 312054630392], [-10444262930948, 316312717343, -1099443415105], [21443794541706, -119877619862, 442534636810], [-2869649584074, 229896738392, 690997019544], [5603436403096, 454075574148, -517893177220], [-22230253038266, 325852251073, 117136082489], [-2246141249870, -206910470760, -202626727512], [-26505181141180, 548330557979, -1298387230741], [-23623529931862, 20376173916, 948671920188], [20480207661984, 294462706838, -1783933762458], [-22411474580530, 644665444520, -289401928936], [31765714328444, -355845180656, 426908500648], [-34271487971812, 96301951284, 680782165356], [-44192546838482, -254841635607, 600098524481], [18753382789428, 316652040292, -839762860404], [1030268630566, -792618388428, -1689775731580], [15736807634170, 90580394422, 1819971892318], [39327019950946, -731814063666, 1496401094910], [-11567029777618, 6227384212, 2013203896900], [30224235586440, 665746700408, -419593489176], [-35173052508706, 725085449424, -1614545773856], [-15327957282960, -287137280122, 2670531382358], [-35292661736822, 169466544897, 739045992201], [-65735118000622, -93697342404, 229491194988], [13199750455668, 813768675489, 1888607836353], [43570459710162, 1085468026693, 1054652181885], [-50823864177856, 1028746794006, -4082248761786], [-27101937452156, 464063277202, -1112818811782], [-40840050897854, -322938511630, 911287621706], [49812607412372, 970103127447, -653302372185], [21787413045622, 1109647636650, -74862354510], [-78234616028842, 858138076915, -426966366869], [-18785398921200, 298722659788, -2136089750396], [-83481961981348, -39629815149, -60543081005], [179047813889336, -177148464984, 492894707416], [46371421871642, -63728171730, 2088009209070], [108167527888448, 542083914512, -985609895584], [-93879032668862, -1671722110934, 1457253113546], [-135400130051256, -354783677416, -42321695688], [14911934864482, 207531351986, 2384417390306], [-2056641119386, 1031062873806, -2479418295138], [58972686856776, 1183079929976, 2629512727016], [-44770995957982, 604662882824, -834648289112], [35040165869240, 74165482328, 2875355333264], [95133626726068, 1587410659163, -163124240629], [177911994559350, -745883307778, -4045545112210], [91344798165782, -626406187296, -39783642704], [63906792746328, 832511297408, 3432089918088], [-107856593585944, -1426656297004, 1214161431524], [-812565578300, 1227858709770, 3415635457058], [-137226004498702, 276419576930, 5170149583922], [-45876273971444, -278533585373, 1707381395971], [-260443627161072, -545233256680, 1729689227336], [-25014949132054, 1816150766808, -6738994049096], [-96260017400148, -295842881201, -113260265489], [-46742927363776, -25396277920, -6178919358128], [-39914412646766, -723937864922, -220094578346], [-169739865486870, 826821291380, -3320172537996], [96008062128260, -1004272431848, -4057291426160], [8454286751400, 1065053185812, -4790243742732], [136434621243956, -922069946938, 4768221197230], [5974662420580, -191792569247, 9107552268193], [167463889026056, 1726176281684, -2829824138140], [72396082068926, -704525765664, 2449018554576], [35753029104478, -370794827452, 8609457939572], [-186457084420712, 1150223673810, -4929098400862], [48294718612896, -293526705080, -641024281016], [-144165450928996, 924765409245, 4561495039597], [35564368671748, -1955157845018, 6352402315678], [88826288946960, 966507170664, -3849580231896], [147832447482018, 1214867853892, 1419714592996], [-166679279869998, 492030060040, 9256385154360], [-404512183911080, 630749301252, -2528152405372], [45908320842426, 130950223376, 6307097748896], [-170459158386958, -4035217188379, -1834139662739], [86789404879212, -1928731737212, -8358069971028], [-37190808025546, -2134361901882, 4924639779702], [-90712733567876, -493935305079, 1864818994137], [-112494573352518, -3493746165651, 3848464107285], [-89003027159578, 2205285732194, 10820142454610], [-213763405187416, -359649550792, -1835637961072], [-102640314202876, -829283927318, -1476746064878], [-190904304210298, 2105834181219, -2339808670053], [-1775807519262, 974173800733, -3720813091163], [-296199348391058, -597653735454, -75948312670], [292586224819868, 1910365732227, 4009657368963], [-263040683807634, 2106434811852, -1374741557364], [197744473764586, -4111545012232, 10286415321224], [-68572445537108, 435734744004, -1316108910564], [178407139915018, 4725856915122, 576138562322], [-223169627292962, 79289102341, 3886391788861], [101658663732052, 1445078441814, -4390700500290], [-157615580997098, 1613913394164, -13186034198364], [-110871811246168, 2264768347044, 15669046551612], [131273466007054, -1489495432992, 9931965611232], [73505325009928, -817741661892, 1121437627932], [-125184843674996, -3035421845414, -8709310405438], [-192995200243762, -251860817124, -13746170236212], [219729535015298, 2126057084466, -11567971493814], [-124892393478356, 4025706160113, 3912902457857], [429791992746928, -1246545723828, 1359989514332], [180084457961240, -796473574176, -4596702814992], [81486727945112, 1129607807314, -9682099494830], [155771554085238, -5237346584281, -7038015337969], [-267305465262836, 278338756527, 21389493544047], [-35307257009304, 2468387429116, -17384038266876], [-47991820547762, 1806078698088, -14167759039608], [132623723710714, -1956684099244, 16968437361092], [189939909355784, 1904623350510, 9225983390574], [-255339220698702, -6655533633840, -7594183400832], [-216753944898722, 4803245020840, -4049280370024], [532014474887700, 4495343376175, -9755823704577], [-859792776618818, -1418703610982, -3397691439694], [-111333072890956, -2670856852391, 338629643737], [-419206778838318, 477833490904, -18233396275304], [-649492271144290, 3498727825557, 16070808699805], [-525881409533200, -5222445123048, 6431300942088], [510915917703002, 552924165535, 1387600097191], [532230638809380, -3132503121677, -24843677649405], [-296734261444572, -380438162951, 12595995987001], [36238250428534, -6636390771774, 98480063058], [614433821059842, -3052433468182, 18567959787210], [330309624722560, 9436676516008, -2182026010760], [-108852430211660, 5378078790098, -13069821265606], [-632471122228876, 3878912864862, -17397390426858], [-72890711099586, 6001915709692, 7555372444732], [911598548490476, -4608897934270, 5796198704794], [-450450459792466, -10747878329097, 7147800099279], [-7544308313584, 6844911778376, 2686412911216], [-263505721911334, 9699367209392, -12980606484880], [550824875659520, 6326171495244, -3706008272996], [21261117553158, 3452373699362, 27583190561058], [483185872673602, -4913839188468, 19178421372620], [477911080821412, 1974538302450, -21033732759654], [433645100367288, -2902970885220, 24342161126556], [-267194558729350, -4740105987744, 11382918658320], [525789409655692, 5576796958439, 1739088403367], [835244295041744, 1409002911792, 9524792985952], [-369057176161842, -5043190578188, -10085878522748], [-203362710149422, 3428632355512, -8015643498632], [470323701577324, -7190691477845, -17240994742133], [416874387225254, 16076448684044, -5565304716628], [487152735699630, 6289362147243, 11216321127123], [409105636927104, -5605843883780, -17575219236932], [-786186732471154, -144254969278, 1293269328730], [-364740513021262, 7884454984554, 38097455239866], [516817099982540, -4306953712446, 12498962873130], [32927098867516, 2361657818967, -5400101186985], [-167109543624856, 13707753399228, -27375945366188], [212332065531066, 1602492178098, 26152744455810], [-450418946776162, 11470619958084, 1942454058516], [804087077608066, -1230939932502, -14894724325606], [1080040469009936, -4379244588138, 30833044058166], [298812450311396, -14313525100195, -6450323989955], [-276370777033372, -2140250063532, 8753659898556], [396054107632764, 689034163671, -26470436418153], [-447282176246610, -7549458037114, 13041747382790], [-557407084310258, 12958873428304, -13831546979104], [-62766330804534, -86727222736, 27505580886224], [570305493330832, 4224022954962, 36694207563810], [-1384970764383878, -2846795340732, 15294036843156], [-255063455027698, -8844912779822, -23949436070], [1147664612598854, -2331665328167, -35572267373951], [-874688337846328, 2159469190788, -4278890870940], [-1392070145342590, -17387571390, 8652689620114], [988497064986972, 6111350301378, -13013610340038], [117115546903334, 9888672624249, 5030078386017], [45702593452460, -14454576681874, -35559433326682], [361528676057920, 15130134646508, 22638760147388], [-543691594145238, 6599078628953, -56209891673055], [1659229895079932, -507251321625, 29652446751495], [53691806197750, -12490620494856, 43228782572088], [2221542856861022, -511455304640, 21625197766480], [-949217003452144, -7834486702342, 14123089793450], [-1361288238897370, -501249429156, 5387534372940], [-1214409656795370, -5081788626348, 27237996715524], [145308159105536, 1322270796050, 6529894979266], [-358413264914796, -20889627865051, 28707985584837], [-400219113681170, -377342423360, -22256326684192], [1001023866053216, 15697327447816, -7109422290320], [-189547371275334, -2842403234132, 66647142885484], [1778367288401578, -2384075202396, -22530517784284], [621619478079432, 14710368374380, -28922825155020], [-1160417680968476, -10107597184860, 44266979294684], [610514817745252, -14765135132733, 9331963099635], [1158067755684238, 8604763126050, 27782304334842], [516324478596290, -9307940431013, 9090449691043], [258600923230384, 15639577496592, -15980717592552], [-307894878722814, -22343862139186, 26591573951894], [-1047879323634836, -8296002509228, -35528394098548], [2439543806293748, 498774327675, -11447151970197], [-650605239565232, -35258696554424, 7740143048072], [14838063155638, 14354616923612, -27624561567652], [824890968370840, 17557576188256, 8311086395968], [-2962770251490686, -8684181699228, -4126838232348], [999421279072076, -15632082265731, -58612764024179], [-45855994854024, -13560329578824, 69268877776224], [2609360633942062, 2708368821684, -947067317244], [345596510222082, 7204857754774, 14672504366262], [119913253115782, 34144211723034, -37912367502870], [-2424056646709250, 11462987802013, -59776237099867], [-1731668370766322, 5305828644074, -11961454355998], [965792896159992, 38177781209176, -29827919326520], [-1155338078814850, -3397683094456, 43710665697448], [2040463173325500, -13791092134393, 43062321133895], [251234301989832, -10928875941584, -107980029199104], [1406931531210800, 2813977891956, 12568655225748], [-28410893019446, -9487435169211, 45246644491917], [1998833433108764, -7878701438776, 39681701855888], [1679480045467168, -11151225033718, 21370959400826], [-338867065016310, 18616821178214, 91832512287950], [-1602358449337030, -1955779106667, 37486173634909], [-2025512723636220, -3153619663180, 6345581573820], [-3577733384799980, -2719236933099, -15935720062347], [2165484853164304, -16617733996164, -106577251288348], [-891483480271706, 19095832870212, 10454052689508], [1716423490359200, -15647672703510, 8722094562810], [1555007521379242, -16864776404182, -3417454228678], [-950609229282396, 21355537875812, -22432178649748], [-1599770418125866, 7540480513818, 35564037220522], [-1246008495851378, -29304785707637, -29019074620493], [1576496723194302, -17371253676616, -64945224537864], [-1905684967615744, 10546234044080, 119212472965664], [-954685590659066, -16113065634758, -38684095449238], [-4048935329992266, -11040726915667, 1269516914469], [-3019644225854872, 7440829266438, -15521686763274], [239250744260626, -8418764239368, -82652223348456], [2024471406771802, -12215828613730, -108321744026650], [-2263233536401964, 27339884874597, -138168134962395], [2019561220283068, -14520382627281, -18693391310257], [1829780004317342, -5275024866532, -88726658209204], [2052768027011114, -3444395458854, -99120758813558], [-438124835036100, 2872233779982, 64569843492294], [-3768855264588148, -13546154488608, 1460307167640], [984324226801494, 2511855179008, 83467641218752], [-807204898545234, -21427198193855, 64354042350249], [1318455868050720, 46312932546748, 15198484595580], [-4028321665528216, 17339952245834, -10372992749398], [-2682931218955554, 1443497143242, 83134891779114], [2982210521595256, -15607053806660, 51621449469260], [-373818079515314, -266320884914, -119098186932754], [-2801886284917958, -9046469188023, 27702784418385], [-440201764900816, -16228753508408, -55527004915928], [-325664267616604, -13730303780417, -90005858881169], [-3039284809589210, -21109695219354, -13853674598106], [-1905594136222574, 33831968383977, -4499283977551], [2040581949081620, 5864673733926, -86263159298546], [2029869721179162, -844193186424, -106578285739128], [-2006398765600124, -8396939733281, -26647863375281], [-2469302109012536, 7728585028114, 24708957244754]]
